summaryrefslogtreecommitdiffstats
path: root/man_macro.c
diff options
context:
space:
mode:
authorIngo Schwarze <schwarze@openbsd.org>2017-01-10 13:47:00 +0000
committerIngo Schwarze <schwarze@openbsd.org>2017-01-10 13:47:00 +0000
commit8d7c45893d14200cf487664ea9966f4c64db548d (patch)
tree1d3d7493d7bb10da3b43ff578cf8b4808127d552 /man_macro.c
parentb0911daecba940ec62df1e631a2f8a01d7ffe641 (diff)
downloadmandoc-8d7c45893d14200cf487664ea9966f4c64db548d.tar.gz
unify names of AST node flags; no change of cpp output
Diffstat (limited to 'man_macro.c')
-rw-r--r--man_macro.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/man_macro.c b/man_macro.c
index 4ea78146..ee144e97 100644
--- a/man_macro.c
+++ b/man_macro.c
@@ -95,7 +95,7 @@ man_unscope(struct roff_man *man, const struct roff_node *to)
/* Reached the end of the document? */
- if (to == NULL && ! (n->flags & MAN_VALID)) {
+ if (to == NULL && ! (n->flags & NODE_VALID)) {
if (man->flags & (MAN_BLINE | MAN_ELINE) &&
man_macros[n->tok].flags & MAN_SCOPED) {
mandoc_vmsg(MANDOCERR_BLK_LINE,
@@ -130,7 +130,7 @@ man_unscope(struct roff_man *man, const struct roff_node *to)
man->last = n;
n = n->parent;
- man->last->flags |= MAN_VALID;
+ man->last->flags |= NODE_VALID;
}
/*
@@ -164,7 +164,7 @@ rew_scope(struct roff_man *man, int tok)
for (;;) {
if (n->type == ROFFT_ROOT)
return;
- if (n->flags & MAN_VALID) {
+ if (n->flags & NODE_VALID) {
n = n->parent;
continue;
}
@@ -356,13 +356,13 @@ in_line_eoln(MACRO_PROT_ARGS)
}
/*
* Append MAN_EOS in case the last snipped argument
* ends with a dot, e.g. `.IR syslog (3).'
*/
if (n != man->last &&
mandoc_eos(man->last->string, strlen(man->last->string)))
- man->last->flags |= MAN_EOS;
+ man->last->flags |= NODE_EOS;
/*
* If no arguments are specified and this is MAN_SCOPED (i.e.,
@@ -356,13 +356,13 @@ in_line_eoln(MACRO_PROT_ARGS)
}
/*
- * Append MAN_EOS in case the last snipped argument
+ * Append NODE_EOS in case the last snipped argument
* ends with a dot, e.g. `.IR syslog (3).'
*/